import { SHAPE } from '@antv/g';
import { Module } from 'mana-syringe';
import { CanvasPickerPlugin, PointInPathPickerFactory } from './CanvasPickerPlugin';
import { isPointInPath as CirclePicker } from './Circle';
import { isPointInPath as EllipsePicker } from './Ellipse';
import { isPointInPath as LinePicker } from './Line';
import { isPointInPath as PolylinePicker } from './Polyline';
import { isPointInPath as PathPicker } from './Path';
import { isPointInPath as RectPicker } from './Rect';
import { isPointInPath as PolygonPicker } from './Polygon';
var containerModule = Module(function (register) {
  register({
    token: PointInPathPickerFactory,
    useFactory: function useFactory(context) {
      return function (tagName) {
        if (tagName === SHAPE.Circle) {
          return CirclePicker;
        } else if (tagName === SHAPE.Ellipse) {
          return EllipsePicker;
        } else if (tagName === SHAPE.Rect) {
          return RectPicker;
        } else if (tagName === SHAPE.Line) {
          return LinePicker;
        } else if (tagName === SHAPE.Polyline) {
          return PolylinePicker;
        } else if (tagName === SHAPE.Polygon) {
          return PolygonPicker;
        } else if (tagName === SHAPE.Path) {
          return PathPicker;
        } else if (tagName === SHAPE.Image || tagName === SHAPE.Text // tagName === SHAPE.Group
        ) {
          return function () {
            return true;
          };
        }

        return null;
      };
    }
  });
  register(CanvasPickerPlugin);
});

var Plugin =
/** @class */
function () {
  function Plugin() {}

  Plugin.prototype.init = function (container) {
    container.load(containerModule, true);
  };

  Plugin.prototype.destroy = function (container) {
    container.remove(PointInPathPickerFactory);
    container.remove(CanvasPickerPlugin);
  };

  return Plugin;
}();

export { Plugin };